<?php

// FastWP Framework - checker

namespace fastwp_horizon_core;

// Do not allow directly accessing this file.
if ( ! defined( 'ABSPATH' ) ) {
	die( 'Direct script access denied.' );
}

class checker {

    function __construct() {
        global $pagenow;
        if ( isset( $_GET['activated'] ) && $pagenow == 'themes.php' ) {
            wp_redirect( admin_url( 'admin.php?page=horizon' ) );
            exit;
        }

        add_action( 'admin_menu', array( 'fastwp_horizon_core\checker', 'admin_menu' ) );
        add_action( 'wp_ajax_fastwp_horizon_save_token', array( 'fastwp_horizon_core\checker', 'save' ) );
        add_action( 'wp_ajax_fastwp_horizon_save_twitter_api', array( 'fastwp_horizon_core\checker', 'save_twitter' ) );
    }

    public static function admin_menu() {
        $menu_page = 'add_' . 'menu_' . 'page';
        $submenu_page = 'add_' . 'submenu_' . 'page';

        // page title, menu title, capability, menu slug, callback, icon, position
    	$menu_page( esc_html__( 'Horizon Theme', 'horizon' ), esc_html__( 'Horizon Theme', 'horizon' ), 'switch_themes', 'horizon', array( 'fastwp_horizon_core\checker', 'admin_menu_markup' ), FASTWP_HORIZON_URI . '/fastwp-framework/assets/img/menu-icon.png', 2 );

        $submenu_page(
            $parent_slug = 'horizon',
            $page_title  = esc_html__( 'Welcome', 'horizon' ),
            $menu_title  = esc_html__( 'Welcome', 'horizon' ),
            $capability  = 'switch_themes',
            $menu_slug   = 'horizon',
            $function    = array( 'fastwp_horizon_core\checker', 'admin_menu_markup' )
        );

        $submenu_page(
            $parent_slug = 'horizon',
            $page_title  = esc_html__( 'Instagram Settings', 'horizon' ),
            $menu_title  = esc_html__( 'Instagram', 'horizon' ),
            $capability  = 'switch_themes',
            $menu_slug   = 'horizon-instagram',
            $function    = array( 'fastwp_horizon_core\checker', 'admin_menu_markup' )
        );

        $submenu_page(
            $parent_slug = 'horizon',
            $page_title  = esc_html__( 'Twitter Settings', 'horizon' ),
            $menu_title  = esc_html__( 'Twitter', 'horizon' ),
            $capability  = 'switch_themes',
            $menu_slug   = 'horizon-twitter',
            $function    = array( 'fastwp_horizon_core\checker', 'admin_menu_markup' )
        );

        $submenu_page(
            $parent_slug = 'horizon',
            $page_title  = esc_html__( 'Support', 'horizon' ),
            $menu_title  = esc_html__( 'Support', 'horizon' ),
            $capability  = 'switch_themes',
            $menu_slug   = 'horizon-support',
            $function    = array( 'fastwp_horizon_core\checker', 'admin_menu_markup' )
        );

    }

    public static function admin_menu_markup() { ?>
        <div class="wrap">
            <h2><?php echo esc_html__( 'Horizon Theme', 'horizon' ); ?></h2>
            <div class="description"><?php echo esc_html__( 'Thank you for choosing Horizon Theme.', 'horizon' ); ?></div>
            <?php settings_errors(); ?>

            <h2 class="nav-tab-wrapper fastwp-nav">
                <a href="?page=horizon" class="<?php echo 'nav-tab ' . ( $_GET['page'] == 'horizon' ? 'nav-tab-active' : '' ); ?>"><?php echo esc_html__( 'Welcome', 'horizon' ); ?></a>
                <a href="?page=horizon-instagram" class="<?php echo 'nav-tab ' . ( $_GET['page'] == 'horizon-instagram' ? 'nav-tab-active' : '' ); ?>"><?php echo esc_html__( 'Instagram Settings', 'horizon' ); ?></a>
                <a href="?page=horizon-twitter" class="<?php echo 'nav-tab ' . ( $_GET['page'] == 'horizon-twitter' ? 'nav-tab-active' : '' ); ?>"><?php echo esc_html__( 'Twitter Settings', 'horizon' ); ?></a>
                <a href="?page=horizon-support" class=<?php echo 'nav-tab ' . ( $_GET['page'] == 'horizon-support' ? 'nav-tab-active' : '' ); ?>"><?php echo esc_html__( 'Support', 'horizon' ); ?></a>
                <?php if( class_exists( 'ReduxFramework' ) ) { ?>
                    <a href="themes.php?page=_options" class="nav-tab"><?php echo esc_html__( 'Theme Options', 'horizon' ); ?></a>
                <?php } ?>
            </h2>


            <?php

            if( $_GET['page'] == 'horizon' ) {

                echo '<div class="fastwp-box"><span class="dashicons dashicons-awards"></span>
                    <section>
                        <h3>' . esc_html__( 'Thank you for purchasing Horizon Theme!', 'horizon' ) . '</h3>
                        ' . esc_html__( 'If you like Horizon please consider leaving a small review and rate our theme on ThemeForest, it would be greatly appreciated.', 'horizon' ) . '
                    </section>
                </div>';

                echo '<div class="fastwp-box fastwp-mt-25">';

                echo '<div class="fastwp-icon-box fastwp-col-4"><span class="dashicons dashicons-sos"></span>
                    <section>
                        <h3><a href="//fastwp.net/support">' . esc_html__( 'Support', 'horizon' ) . '</a></h3>
                        ' . esc_html__( 'Do you have questions regarding Horizon or are you in need of support? Our Professional theme is here to help you!', 'horizon' ) . '
                    </section>
                </div>';

                if( class_exists( 'ReduxFramework' ) ) {

                echo '<div class="fastwp-icon-box fastwp-col-4"><span class="dashicons dashicons-admin-settings"></span>
                    <section>
                        <h3><a href="themes.php?page=_options">' . esc_html__( 'Theme Options', 'horizon' ) . '</a></h3>
                        ' . esc_html__( 'It is meant to make your life easier by offering you Customization options for your website. Here you can set all general options that affects the entire website.', 'horizon' ) . '
                    </section>
                </div>';

                }

                echo '<div class="fastwp-icon-box fastwp-col-4">
                    <img src="' . FASTWP_HORIZON_URI . '/fastwp-framework/assets/img/logo.svg" alt="' . esc_attr__( 'Logo', 'horizon' ) . '" />
                    <section>
                        <h3>FastWP</h3>
                        ' . sprintf( esc_html__( 'Visit our website %s', 'horizon' ), '<a href="//fastwp.net" target="_Blank">FastWP.net</a>' ) . '
                    </section>
                </div>';

                echo '</div>';

            } else if( $_GET['page'] == 'horizon-support' )  {

                echo '<div class="fastwp-box fastwp-d-block">
                <h3>' . esc_html__( 'Do you have questions regarding Horizon or are you in need of support? Our Professional theme is here to help you!', 'horizon' ) . '</h3>

                ' . esc_html__( 'Offering quality services and support since 2013. With every purchase of an FastWP Themes product you benefit from 6 months of free premium support. We provide our customers friendly, timely and carefully detailed support.
                You can open a support ticket any time on our support platform linked down bellow.', 'horizon' ) . '
                </div>
                
                <a href="//fastwp.net/support" class="fastwp-button fastwp-mt-25" target="_blank">' . esc_html__( 'Open A Ticket', 'horizon' ) . '</a>';

            } else if( $_GET['page'] == 'horizon-instagram' ) {

                echo '<form action="#" class="horizon-theme-options horizon-save-form">';
                echo '<h3>' . esc_html__( 'Instagram Access Token', 'horizon' ) . '</h3>
                <input type="text" name="access_token" value="' . esc_attr( get_option( 'horizon_access_token' ) ) . '" />';
                echo '<button>' . esc_html__( 'Save Access Token', 'horizon' ) . '</button>';
                echo '</form>';

                echo esc_html__( 'or', 'horizon' ) . ' <a href="#" class="fastwp-show-next">' . esc_html__( 'generate a token', 'horizon' ) . '</a>';

                echo '<form action="https://api.instagram.com/oauth/authorize/" class="horizon-theme-options" style="display:none;margin-top:20px;">';
                echo '<h3>' . esc_html__( 'Client ID', 'horizon' ) . '</h3><input type="text" name="client_id" value="" />
                <input type="hidden" name="redirect_uri" value="' . admin_url( 'admin.php?page=horizon-instagram' ) . '" />
                <input type="hidden" name="response_type" value="token" />';
                echo '<button>' . esc_html__( 'Generate Access Token', 'horizon' ) . '</button>';
                echo '</form>'; ?>

                <script type="text/javascript" >
                    jQuery(document).ready(function($) {

                        var hash = window.location.hash.split( '#access_token=' );

                        if( hash[1] != undefined ) {
                            $( 'form' ).find( 'input[name="access_token"]' ).val( hash[1] );
                        }

                        $('.horizon-save-form').on('submit', function(e) {
                            e.preventDefault();

                            var form = $(this);

                            var data = {
                                action: 'fastwp_horizon_save_token',
                                access_token: $(this).find('input[name="access_token"]').val(),
                                _ajax_nonce: '<?php echo wp_create_nonce( 'fastwp_horizon_save_token' ); ?>'

                            };

                            form.append( '<div class="fastwp-overlay"></div>' +
                            '<img src="<?php echo FASTWP_HORIZON_URI; ?>/fastwp-framework/assets/img/loader.svg" alt="' . esc_attr__( 'Loader', 'horizon' ) . '" class="loader" />' );

                            var ajaxurl = '<?php echo admin_url( 'admin-ajax.php' ); ?>';

                            $.post( ajaxurl, data, function( response ) {
                                var alert = form.find( '.fastwp-alerts' );
                                if( response.error == true ) {
                                    if( alert.length > 0 ) {
                                        alert.removeClass( 'fastwp-success' ).addClass( 'fastwp-warning' ).text( response.message );
                                    } else {
                                        form.prepend( '<div class="fastwp-alerts fastwp-warning">' + response.message + '</div>' );
                                    }
                                } else {
                                    if( alert.length > 0 ) {
                                        alert.removeClass( 'fastwp-warning' ).addClass( 'fastwp-success' ).text( response.message );
                                    } else{
                                        form.prepend( '<div class="fastwp-alerts fastwp-success">' + response.message + '</div>' );
                                    }
                                }

                                form.find( 'img.loader,.fastwp-overlay' ).fadeOut(100);

                            }, "json" );
                        });

                        $('.fastwp-show-next').on( 'click', function(e) {
                            e.preventDefault();
                            $(this).next().fadeIn(100);
                        });

                    });
                </script>

            <?php } else if( $_GET['page'] == 'horizon-twitter' ) {

                echo '<form action="#" class="horizon-theme-options horizon-save-form">';
                echo '<h2>' . esc_html__( 'Consumer API keys', 'horizon' ) . '</h2>';
                echo '<h3>' . esc_html__( 'API Key', 'horizon' ) . '</h3>
                <input type="text" name="api_key" value="' . esc_attr( get_option( 'horizon_twitter_api_key' ) ) . '" />';
                echo '<h3>' . esc_html__( 'Secret API Key', 'horizon' ) . '</h3>
                <input type="text" name="secret_api_key" value="' . esc_attr( get_option( 'horizon_twitter_api_secret_key' ) ) . '" />';
                echo '<h2>Access token & access token secret</h2>';
                echo '<h3>' . esc_html__( 'Access Token', 'horizon' ) . '</h3>
                <input type="text" name="access_token" value="' . esc_attr( get_option( 'horizon_twitter_access_token' ) ) . '" />';
                echo '<h3>' . esc_html__( 'Access Token Secret', 'horizon' ) . '</h3>
                <input type="text" name="access_token_secret" value="' . esc_attr( get_option( 'horizon_twitter_access_token_secret' ) ) . '" />';
                echo '<button>' . esc_html__( 'Save', 'horizon' ) . '</button>';
                echo '</form>'; ?>

                <script type="text/javascript" >
                    jQuery(document).ready(function($) {

                        $('.horizon-save-form').on('submit', function(e) {
                            e.preventDefault();

                            var form = $(this);

                            var data = {
                                action: 'fastwp_horizon_save_twitter_api',
                                api_key: $(this).find('input[name="api_key"]').val(),
                                api_secret_key: $(this).find('input[name="secret_api_key"]').val(),
                                access_token: $(this).find('input[name="access_token"]').val(),
                                access_token_secret: $(this).find('input[name="access_token_secret"]').val(),
                                _ajax_nonce: '<?php echo wp_create_nonce( 'fastwp_horizon_save_twitter_api' ); ?>'

                            };

                            form.append( '<div class="fastwp-overlay"></div>' +
                            '<img src="<?php echo FASTWP_HORIZON_URI; ?>/fastwp-framework/assets/img/loader.svg" alt="' . esc_attr__( 'Loader', 'horizon' ) . '" class="loader" />' );

                            var ajaxurl = '<?php echo admin_url( 'admin-ajax.php' ); ?>';

                            $.post( ajaxurl, data, function( response ) {
                                var alert = form.find( '.fastwp-alerts' );
                                if( response.error == true ) {
                                    if( alert.length > 0 ) {
                                        alert.removeClass( 'fastwp-success' ).addClass( 'fastwp-warning' ).text( response.message );
                                    } else {
                                        form.prepend( '<div class="fastwp-alerts fastwp-warning">' + response.message + '</div>' );
                                    }
                                } else {
                                    if( alert.length > 0 ) {
                                        alert.removeClass( 'fastwp-warning' ).addClass( 'fastwp-success' ).text( response.message );
                                    } else{
                                        form.prepend( '<div class="fastwp-alerts fastwp-success">' + response.message + '</div>' );
                                    }
                                }

                                form.find( 'img.loader,.fastwp-overlay' ).fadeOut(100);

                            }, "json" );
                        });

                    });
                </script>

            <?php } ?>

        </div>

    <?php }

    public static function save() {
        // check if ajax call is valid
        check_ajax_referer( 'fastwp_horizon_save_token' );
        // access token
        $license = isset( $_POST['access_token'] ) ? $_POST['access_token'] : '';
        // update license key
        if( get_option( 'horizon_access_token' ) !== false ) {
            update_option( 'horizon_access_token', $license );
        } else add_option( 'horizon_access_token', $license );

        echo json_encode( array( 'error' => false, 'message' => esc_html__( 'Saved !', 'horizon' ) ) );

        wp_die();
    }

    public static function save_twitter() {
        // check if ajax call is valid
        check_ajax_referer( 'fastwp_horizon_save_twitter_api' );
        // api key
        $api_key = isset( $_POST['api_key'] ) ? $_POST['api_key'] : '';
        // secret api key
        $secret_api_key = isset( $_POST['api_secret_key'] ) ? $_POST['api_secret_key'] : '';
        // access token
        $access_token = isset( $_POST['access_token'] ) ? $_POST['access_token'] : '';
        // access token secret
        $access_token_secret = isset( $_POST['access_token_secret'] ) ? $_POST['access_token_secret'] : '';
        // update api key
        if( get_option( 'horizon_twitter_api_key' ) !== false ) {
            update_option( 'horizon_twitter_api_key', $api_key );
        } else add_option( 'horizon_twitter_api_key', $api_key );
        // update secret api key
        if( get_option( 'horizon_twitter_api_secret_key' ) !== false ) {
            update_option( 'horizon_twitter_api_secret_key', $secret_api_key );
        } else add_option( 'horizon_twitter_api_secret_key', $secret_api_key );
        // access token
        if( get_option( 'horizon_twitter_access_token' ) !== false ) {
            update_option( 'horizon_twitter_access_token', $access_token );
        } else add_option( 'horizon_twitter_access_token', $access_token );
        // access token secret
        if( get_option( 'horizon_twitter_access_token_secret' ) !== false ) {
            update_option( 'horizon_twitter_access_token_secret', $access_token_secret );
        } else add_option( 'horizon_twitter_access_token_secret', $access_token_secret );

        echo json_encode( array( 'error' => false, 'message' => esc_html__( 'Saved !', 'horizon' ) ) );

        wp_die();
    }

}