<?php

// FastWP Framework - Redux

namespace fastwp_horizon_core;

// Do not allow directly accessing this file.
if ( ! defined( 'ABSPATH' ) ) {
	die( 'Direct script access denied.' );
}

class redux {

    private $sections = array();
    private $args = array();

    function __construct() {

        if( !class_exists( 'ReduxFramework' ) ) {
            return;
        }

        // Just for demo purposes. Not needed per say.
        $this->theme = wp_get_theme();

        // Set the default arguments
        $this->setArguments();


        // Create the sections and fields
        $this->getSections();

        if ( !isset( $this->args['opt_name'] ) ) { // No errors please
            return;
        }

        $this->ReduxFramework = new \ReduxFramework($this->sections, $this->args);

    }

    public static function all_posts() {
        $args = array(
            'numberposts' => '-1',
            'orderby'     => 'name',
            'order'       => 'ASC',
        );

        $posts = array();

        foreach( get_posts( $args ) as $item ) {
            $posts[$item->ID] = $item->post_title;
        }

        return $posts;
    }

    public function getSections() {

        $this->sections[] = array(
            'icon'      => 'el-icon-wrench',
            'title'     => esc_html__('General', 'horizon'),
            'fields'    => array(
                array(
                    'id'        => 'opt-info-field',
                    'type'      => 'info',
                    'title'     => esc_html__( 'Welcome to Horizon Options Panel.', 'horizon' ),
                    'desc'      => esc_html__( 'It is meant to make your life easier by offering you options which will customize your website. Here you can set all general options that affects entire website.', 'horizon' )
                ),
                array(
                    'id'        => 'custom_logo_text',
                    'type'      => 'text',
                    'title'     => esc_html__( 'Logo Text', 'horizon' ),
                ),
                array(
                    'id'        => 'fwp_custom_js',
                    'type'      => 'ace_editor',
                    'title'     => esc_html__( 'Custom JS', 'horizon' ),
                    'subtitle'  => esc_html__( 'Paste your JavaScript code here. Use this field to quickly add JS code snippets.', 'horizon' ),
                    'mode'      => 'javascript',
                    'theme'     => 'chrome',
                    'default'   => ""
                ),
                array(
                    'id'        => 'fwp_gmap_key',
                    'type'      => 'text',
                    'title'     => esc_html__( 'Google Maps API Key', 'horizon' ),
                    'subtitle'  => __( '<a href="https://www.youtube.com/watch?v=-UCHsqxBqwY" target="_blank">How to generate your api key ?</a>', 'horizon' ),
                )
            )
        );

        $this->sections[] = array(
            'icon'      => 'el el-fast-forward',
            'title'     => esc_html__( 'Preloader Options', 'horizon' ),
            'fields'    => array(
                array(
                    'id'        => 'show_preloader',
                    'type'      => 'switch',
                    'title'     => esc_html__( 'Show preloader', 'horizon' ),
                    'subtitle'  => esc_html__( 'Enable/Disable preloader.', 'horizon' ),
                    'default'   => 1,
                    'on'        => 'Enabled',
                    'off'       => 'Disabled'
                ),
            )

        );

        $this->sections[] = array(
            'icon'      => 'el-icon-th-list',
            'title'     => esc_html__( 'Menu', 'horizon' ),
            'fields'    => array(
        		array(
        			'id'        => 'menu_contact_address',
        			'type'      => 'textarea',
                    'default'   => '',
                    'description'=> esc_html__( 'Lines separated with comma', 'horizon' ),
        			'title'     => esc_html__( 'Address Lines', 'horizon' )
        		),
        		array(
        			'id'        => 'menu_contact_email',
        			'type'      => 'text',
                    'default'   => '',
        			'title'     => esc_html__( 'Contact Email', 'horizon' )
        		),
        		array(
        			'id'        => 'menu_contact_phone',
        			'type'      => 'text',
                    'default'   => '',
        			'title'     => esc_html__( 'Contact Phone No.', 'horizon' )
        		),
            )
        );

        $this->sections[] = array(
            'icon'      => 'el-icon-th-list',
            'title'     => esc_html__( 'Blog', 'horizon' ),
            'fields'    => array(
                array(
                    'id'        => 'fwp_blog_type',
                    'type'      => 'select',
                    'title'     => esc_html__( 'Blog Type', 'horizon' ),
                    'options'   => array(
                                        ''          => esc_html__( 'Grid', 'horizon' ),
                                        'grid-bg'   => esc_html__( 'Grid Without Background', 'horizon' ),
                                        'list'      => esc_html__( 'List', 'horizon' )
                                        ),
                ),
                array(
                    'id'        => 'fwp_blog_sidebar',
                    'type'      => 'select',
                    'title'     => esc_html__( 'Sidebar', 'horizon' ),
                    'options'   => array(
                                        ''          => esc_html__( 'Right (default)', 'horizon' ),
                                        'left'      => esc_html__( 'Left', 'horizon' ),
                                        'no_sb'     => esc_html__( 'No Sidebar', 'horizon' )
                                        ),
                    'required'  => array( 'fwp_blog_type', 'equals', array( 'list' ) )
                ),
                array(
                    'id'        => 'fwp_featured_posts_type',
                    'type'      => 'select',
                    'title'     => esc_html__( 'Show Featured Posts', 'horizon' ),
                    'options'   => array(
                                        ''          => esc_html__( 'No', 'horizon' ),
                                        'grid'      => esc_html__( 'Grid (up to 3 posts)', 'horizon' ),
                                        'slider'    => esc_html__( 'Slider', 'horizon' ),
                                        'hero'      => esc_html__( 'Hero Post (a single post displayed)', 'horizon' )
                                        )
                ),
                array(
                    'id'        => 'hero_posts_slider_l',
                    'type'      => 'repeater',
                    'title'     => esc_html__( 'Featured Posts', 'horizon' ),
                    'fields'    => array(
                                        array(
                                            'id'        => 'fwp_blog_featured_posts',
                                            'type'      => 'select',
                                            'title'     => esc_html__( 'Post', 'horizon' ),
                                            'options'   => self::all_posts()
                                        )
                                    ),
                    'required'  => array( 'fwp_featured_posts_type', 'equals', array( 'grid', 'slider', 'hero' ) )
                ),
                array(
                    'id'        => 'fwp_search_box',
                    'type'      => 'select',
                    'title'     => esc_html__( 'Search Box', 'horizon' ),
                    'options'   => array(
                                        ''          => esc_html__( 'None', 'horizon' ),
                                        'before'    => esc_html__( 'Before Posts', 'horizon' ),
                                        'over'      => esc_html__( 'Box With Background', 'horizon' )
                                        )
                ),
        		array(
        			'id'        => 'fwp_search_box_el',
        			'type'      => 'sorter',
        			'title'     => esc_html__( 'Search Box Elements', 'horizon' ),
                    'options'   => array(
                        'elements'  => array(
                            'text'      => esc_html__( 'Text Field', 'horizon' ),
                            'category'  => esc_html__( 'Category', 'horizon' ),
                            'author'    => esc_html__( 'Author', 'horizon' )
                        ),
                        'disabled'  => array(
                        )
                    ),
                    'required'  => array( 'fwp_search_box', 'equals', array( 'before', 'over' ) )
        		),
                array(
                    'id'        => 'fwp_blog_date_meta',
                    'type'      => 'switch',
                    'title'     => esc_html__( 'Hide Date Info', 'horizon' ),
                    'subtitle'  => esc_html__( 'Shows or hides the date information on single.', 'horizon' ),
                    'on'        => 'Yes',
                    'off'       => 'No',
                    'default'   => false,
                ),
            )
        );

        $this->sections[] = array(
            'icon'      => 'el-icon-upload',
            'title'     => esc_html__('Header', 'horizon'),
            'fields'    => array(
                array(
                    'id'        => 'header_links',
                    'type'      => 'multi_text',
                    'title'     => esc_html__( 'Header Icons', 'horizon' ),
                    'desc'      => esc_html__( 'Icon | URL (example: fa fa-facebook | https://mywebsite.ext)', 'horizon' )
                ),
                array(
                    'id'        => 'fwp_before_header',
                    'type'      => 'select',
                    'title'     => esc_html__( 'Show ', 'horizon' ),
                    'options'   => array(
                                        ''          => esc_html__( 'No', 'horizon' ),
                                        'ads'       => esc_html__( 'Ads', 'horizon' ),
                                        'slider'    => esc_html__( 'Slider', 'horizon' )
                                        )
                ),
                array(
                    'id'        => 'fwp_header_ads',
                    'type'      => 'textarea',
                    'title'     => esc_html__( 'Place your AD code here', 'horizon' ),
                    'required'  => array( 'fwp_before_header', 'equals', array( 'ads' ) )
                ),
                array(
                    'id'        => 'header_posts_slider_l',
                    'type'      => 'repeater',
                    'title'     => esc_html__( 'Slider Posts', 'horizon' ),
                    'fields'    => array(
                                        array(
                                            'id'        => 'fwp_blog_header_slider',
                                            'type'      => 'select',
                                            'title'     => esc_html__( 'Post', 'horizon' ),
                                            'options'   => self::all_posts()
                                        )
                                    ),
                    'required'  => array( 'fwp_before_header', 'equals', array( 'slider' ) )
                ),
            )
        );

        $this->sections[] = array(
            'icon'      => 'el-icon-download',
            'title'     => esc_html__('Footer', 'horizon'),
            'fields'    => array(
                array(
                    'id'        => 'footer_style_type',
                    'type'      => 'select',
                    'title'     => esc_html__( 'Show Featured Posts', 'horizon' ),
                    'options'   => array(
                                        'style1'    => esc_html__( 'Style 1', 'horizon' ),
                                        'style2'    => esc_html__( 'Style 2', 'horizon' )
                                        )
                ),
                array(
                    'id'        => 'footer_copyright_text',
                    'type'      => 'textarea',
                    'title'     => esc_html__( 'Copyright Text', 'horizon' ),
                    'required'  => array( 'footer_style_type', 'equals', array( 'style1' ) )
                ),
                array(
                    'id'        => 'footer_about_title',
                    'type'      => 'text',
                    'title'     => esc_html__( 'Title "About Me"', 'horizon' ),
                    'required'  => array( 'footer_style_type', 'equals', array( 'style2' ) )
                ),
                array(
                    'id'        => 'footer_about_text',
                    'type'      => 'textarea',
                    'title'     => esc_html__( '"About Me" Text', 'horizon' ),
                    'desc'      => esc_html__( 'A short description about you', 'horizon' ),
                    'required'  => array( 'footer_style_type', 'equals', array( 'style2' ) )
                ),
                array(
                    'id'        => 'footer_about_image',
                    'type'      => 'media',
                    'title'     => esc_html__( '"About Me" Image', 'horizon' ),
                    'desc'      => esc_html__( 'Example: signature', 'horizon' ),
                    'required'  => array( 'footer_style_type', 'equals', array( 'style2' ) )
                ),
        		array(
        			'id'        => 'footer_count_tags',
        			'type'      => 'text',
                    'default'   => 10,
        			'title'     => esc_html__( 'Popular Tags Limit', 'horizon' )
        		),
                array(
                    'id'         => 'footer_related_posts_l',
                    'type'       => 'repeater',
                    'title'     => esc_html__( 'Featured Posts', 'horizon' ),
                    'fields'    => array(
                                        array(
                                            'id'        => 'footer_featured_posts',
                                            'type'      => 'select',
                                            'title'     => esc_html__( 'Post', 'horizon' ),
                                            'options'   => self::all_posts()
                                        )
                                    )
                ),
        		array(
        			'id'        => 'footer_subscribe_form',
        			'type'      => 'checkbox',
                    'default'   => '',
        			'title'     => esc_html__( 'Subscribe Box', 'horizon' )
        		),
        		array(
        			'id'        => 'footer_subscribe_form_title',
        			'type'      => 'text',
                    'default'   => '',
        			'title'     => esc_html__( 'Subscribe Form Title', 'horizon' ),
                    'required'  => array( 'footer_subscribe_form', 'equals', array( '1' ) )
        		),
        		array(
        			'id'        => 'footer_subscribe_form_subtitle',
        			'type'      => 'text',
                    'default'   => '',
        			'title'     => esc_html__( 'Subscribe Form Subtitle', 'horizon' ),
                    'required'  => array( 'footer_subscribe_form', 'equals', array( '1' ) )
        		),
        		array(
        			'id'        => 'footer_subscribe_form_shortcode',
        			'type'      => 'text',
                    'default'   => '',
        			'title'     => esc_html__( 'Subscribe Form Shortcode', 'horizon' ),
                    'required'  => array( 'footer_subscribe_form', 'equals', array( '1' ) )
        		),
            )
        );

    }

    public static function getMetaboxes( $metaboxes ) {

        $gallery = array( array(
            	'icon' => 'el-icon-screen',
            	'fields' => array(
                    array(
                        'id'       => 'gallery-images',
                        'type'     => 'gallery',
                        'title'    => esc_html__('Gallery Images', 'horizon'),
                    )
                )
            )
        );

        $video = array( array(
            	'icon' => 'el-icon-screen',
            	'fields' => array(
                    array(
                        'id'       => 'video',
                        'type'     => 'text',
                        'multi'    => true,
                        'title'    => esc_html__( 'Video URL', 'horizon'),
                    )
                )
            )
        );

        // Declare metaboxes

        $metaboxes[] = array(
		    'id'            => 'gallery-options',
            'title'         => esc_html__( 'Gallery Options', 'horizon' ),
            'post_types'    => array( 'post' ),
            'post-format'   => array( 'gallery' ),
            'position'      => 'normal', // normal, advanced, side
            'priority'      => 'high', // high, core, default, low - Priorities of placement
            'sections'      => $gallery
        );

        $metaboxes[] = array(
		    'id'            => 'video-options',
            'title'         => esc_html__( 'Video Format Options', 'horizon' ),
            'post_types'    => array( 'post' ),
            'post-format'   => array( 'video' ),
            'position'      => 'normal', // normal, advanced, side
            'priority'      => 'high', // high, core, default, low - Priorities of placement
            'sections'      => $video
        );

        return $metaboxes;
    }

    public function setArguments() {

        $theme = wp_get_theme(); // For use with some settings. Not necessary.

        $this->args = array(
            // TYPICAL -> Change these values as you need/desire
            'opt_name'          => 'fastwp_horizon_data',            // This is where your data is stored in the database and also becomes your global variable name.
            'display_name'      => $theme->get('Name'),     // Name that appears at the top of your panel
            'display_version'   => $theme->get('Version'),  // Version that appears at the top of your panel
            'menu_type'         => 'submenu',                  //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
            'allow_sub_menu'    => true,                    // Show the sections below the admin menu item or not
            'menu_title'        => esc_html__('Theme Options', 'horizon'),
            'page_title'        => esc_html__('Theme Options', 'horizon'),

            // You will need to generate a Google API key to use this feature.
            // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
            'google_api_key' => 'AIzaSyBPVwg6CaFLmKlxYjQu0bJGpxDN1p04S-Q', // Must be defined to add google fonts to the typography module

            'async_typography'  => false,                    // Use a asynchronous font on the front end or font string
            'admin_bar'         => true,                    // Show the panel pages on the admin bar
            'global_variable'   => '',                      // Set a different name for your global variable other than the opt_name
            'dev_mode'          => false,                    // Show the time the page took to load, etc
            'customizer'        => true,                    // Enable basic customizer support

            // OPTIONAL -> Give you extra features
            'page_priority'     => null,                    // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
            'page_parent'       => 'themes.php',            // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
            'page_permissions'  => 'manage_options',        // Permissions needed to access the options panel.
            'menu_icon'         => '',                      // Specify a custom URL to an icon
            'last_tab'          => '',                      // Force your panel to always open to a specific tab (by id)
            'page_icon'         => 'icon-themes',           // Icon displayed in the admin panel next to your menu_title
            'page_slug'         => '_options',              // Page slug used to denote the panel
            'save_defaults'     => true,                    // On load save the defaults to DB before user clicks save or not
            'default_show'      => false,                   // If true, shows the default value next to each field that is not the default value.
            'default_mark'      => '',                      // What to print by the field's title if the value shown is default. Suggested: *

            // CAREFUL -> These options are for advanced use only
            'transient_time'    => 60 * MINUTE_IN_SECONDS,
            'output'            => true,                    // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
            'output_tag'        => true,                    // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
            // 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.

            // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
            'database'              => '', // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
            'show_import_export'    => true, // REMOVE
            'system_info'           => false, // REMOVE

            // HINTS
            'hints' => array(
                'icon'          => 'icon-question-sign',
                'icon_position' => 'right',
                'icon_color'    => 'lightgray',
                'icon_size'     => 'normal',
                'tip_style'     => array( 'color' => 'light', 'shadow' => true, 'rounded' => false, 'style' => '' ),
                'tip_position'  => array( 'my' => 'top left',  'at' => 'bottom right' ),
                'tip_effect'    => array(
                    'show'      => array( 'effect' => 'slide', 'duration' => '500', 'event' => 'mouseover' ),
                    'hide'      => array( 'effect' => 'slide', 'duration'  => '500', 'event' => 'click mouseleave' ),
                ),
            )
        );

        // SOCIAL ICONS -> Setup custom links in the footer for quick links in your panel footer icons.
        $this->args['share_icons'][] = array(
            'url'   => 'http://twitter.com/fastwp',
            'title' => 'Follow FastWP on Twitter',
            'icon'  => 'el-icon-twitter'
        );
        $this->args['share_icons'][] = array(
            'url'   => 'http://themeforest.net/user/fastwp/portfolio',
            'title' => 'Fastwp Official Page',
            'icon'  => 'el-icon-link'
        );
        $this->args['share_icons'][] = array(
            'url'   => 'mailto:themes@fastwp.net',
            'title' => 'Send an email to fastwp',
            'icon'  => 'el-icon-envelope'
        );

    }

}

// Init filters & actions

add_action( 'redux/metaboxes/fastwp_horizon_data/boxes', array( 'fastwp_horizon_core\redux', 'getMetaboxes' ) );