<?php

// FastWP Framework - filters

namespace fastwp_horizon_theme;

// Do not allow directly accessing this file.
if ( ! defined( 'ABSPATH' ) ) {
    die( 'Direct script access denied.' );
}

class filters extends \fastwp_horizon_core\main {

    /* Custom search form */

    public static function search_form() {
        return '<div class="widget widget-search br-none">
					<form method="get" action="' . esc_url( home_url( '/' ) ) . '">
						<input type="text" name="s" placeholder="' . esc_attr__( 'Enter Your Keywords', 'horizon' ) . '">
						<button type="submit"><i class="fa fa-search"></i></button>
					</form>
				</div>';
    }

    /* Custom login form */

    public static function password_protected_form() {
        return '<div class="widget widget-search br-none">
					<form method="post" action="' . esc_url( site_url( 'wp-login.php?action=postpass', 'login_post' ) ) . '">
						<input type="text" name="post_password" placeholder="' . esc_attr__( 'Enter The Password', 'horizon' ) . '">
						<button type="submit"><i class="fa fa-unlock"></i></button>
					</form>
				</div>';
    }

    /* Footer content */

    public static function footer_content() {
		global $fastwp_horizon_custom_js;
        if( !empty( $fastwp_horizon_custom_js ) ) {
		    wp_localize_script( 'custom', 'fastwp', $fastwp_horizon_custom_js );
        }
        if( \fastwp_horizon_theme\utils::get_option( 'fwp_custom_js' ) != '' ) {
            echo '<script>';
            echo \fastwp_horizon_theme\utils::get_option( 'fwp_custom_js' );
            echo '</script>';
        }
    }

    /* Comment form */

    public static function comment_form_args() {
        global $user_identity;

        $commenter  = wp_get_current_commenter();
        $req        = get_option( 'require_name_email' );
        $aria_req   = ( $req ? " aria-required='true'" : '' );

        $args = array(
            'id_form'           => 'commentform',
            'class_form'        => '',
            'id_submit'         => 'submit',
            'class_submit'      => 'lnk-default',
            'name_submit'       => 'submit',
            'title_reply'       => '<strong>' . esc_html__( 'Leave a Reply', 'horizon' ) . '</strong>',
            'title_reply_to'    => '<strong>' . esc_html__( 'Leave a Reply to %s', 'horizon' ) . '</strong>',
            'cancel_reply_link' => esc_html__( 'Cancel Reply', 'horizon' ),
            'label_submit'      => esc_html__( 'Post Comment', 'horizon' ),
            'format'            => 'xhtml',
            'comment_field'     => '<div class="form-field">
                                        <textarea name="comment" id="comment" placeholder="' . esc_attr__( 'Your Comment', 'horizon' ) . '"></textarea>
                                    </div>',
            'must_log_in'       => '<div class="form-field">
                                        <p class="must-log-in">' . sprintf( __( 'You must be <a href="%s">logged in</a> to post a comment.', 'horizon' ), esc_url( wp_login_url( apply_filters( 'the_permalink', get_permalink() ) ) ) ) . '</p>
                                    </div>',
            'logged_in_as'      => '<div class="form-field">
                                        <p class="logged-in-as">' .
                                            sprintf(
                                            __( 'Logged in as <a href="%1$s">%2$s</a>. <a href="%3$s" title="Log out of this account">Log out?</a>', 'horizon' ),
                                              admin_url( 'profile.php' ),
                                              $user_identity,
                                              esc_url( wp_logout_url( apply_filters( 'the_permalink', get_permalink( ) ) ) )
                                            ) . '
                                        </p>
                                    </div>',
            'comment_notes_before'
                                => '<div class="form-field">
                                        <p>' . esc_html__( 'Your email address will not be published. Required fields are marked *', 'horizon' ) . '</p>
                                    </div>',
            'submit_button'     => '<div class="form-field">
                                        <input name="%1$s" type="submit" id="%2$s" class="%3$s" value="%4$s" />
                                    </div>',
            'fields'            => array(
                                    'author' =>
                                    '<div class="form-field">
                                        <input name="author" id="author" placeholder="' . esc_attr__( 'Your Name', 'horizon' ) . ( $req ? '*' : '' ) . '" type="text"' . $aria_req . ' />
                                    </div>',

                                    'email' =>
                                    '<div class="form-field">
                                        <input name="email" id="email" placeholder="' . esc_attr__( 'Email', 'horizon' ) . ( $req ? '*' : '' ) . '" type="email"' . $aria_req . ' />
                                    </div>',

                                    'url' =>
                                    '<div class="form-field">
                                        <input name="url" id="url" placeholder="' . esc_attr__( 'URL', 'horizon' ) . '" type="text" />
                                    </div>'
                                )
        );

        return $args;
    }

    /* Reply link filter */

    public static function comment_reply_link( $link ) {
        return str_replace( 'comment-reply-link', 'reply comment-reply-link', $link );
    }

    /* Markup before comment form */

    public static function before_comment_form() {
        echo '<div class="post-comments">';
    }

    /* Markup after comment form */

    public static function after_comment_form() {
        echo '</div>';
    }

    /* Comment */

    public static function comment( $comment, $args, $depth ) {
        switch ( $comment->comment_type ) {

        case 'pingback':
        case 'trackback': ?>

        <li class="pingback-comment"><p><?php esc_html_e( 'Pingback:', 'horizon' ); ?> <?php comment_author_link(); ?> <?php edit_comment_link( esc_html__( 'Edit', 'horizon' ), ' / <i class="edit-link">', '</i>' ); ?></p>

        <?php break;
        default: ?>

        <li>
            <div class="comment clearfix">
                <div class="commenter-img">
                    <img src="<?php echo get_avatar_url( get_comment_author_email() ); ?>" alt="<?php echo esc_attr( get_comment_author() ); ?>" />
                </div>
                <div class="comment-say">
                    <h3><a href="#"><?php echo get_comment_author(); ?></a> <span><?php echo get_comment_date(); ?></span></h3>
                    <?php comment_text(); ?>
                    <?php echo str_replace( 'comment-reply-link', 'comment-reply-link lnk-default', get_comment_reply_link( array_merge( $args, array( 'reply_text' => esc_html__( 'Reply', 'horizon' ), 'before'=> '', 'after' => '', 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ) ); ?>
                </div>
            </div>

        <?php break;
        }
    }

    /* Comment close tag */

    public static function comment_close_tag( $post = 0 ) { ?>
        </li>
    <?php }

    public static function save_attachment_location( $attachment_id ) {
        if ( isset( $_REQUEST['attachments'][$attachment_id]['gallery_height'] ) ) {
            $location = $_REQUEST['attachments'][$attachment_id]['gallery_height'];
            update_post_meta( $attachment_id, 'gallery_height', $location );
        }
        if ( isset( $_REQUEST['attachments'][$attachment_id]['gallery_width'] ) ) {
            $location = $_REQUEST['attachments'][$attachment_id]['gallery_width'];
            update_post_meta( $attachment_id, 'gallery_width', $location );
        }
    }

    public static function image_attachment_fields_to_edit( $form_fields, $post ) {
        $def_height = get_post_meta( $post->ID, 'gallery_height', true );
        $def_width  = get_post_meta( $post->ID, 'gallery_width', true );

        $form_fields["gallery_height"] = array(
            'label' =>  esc_html__( 'Portfolio Template Height', 'horizon' ),
            'input' =>  'html',
            'html'  =>  '<select name="attachments[' . $post->ID . '][gallery_height]">
                            <option value=""' . ( !in_array( $def_height, array( 'h2' ) ) ? ' selected' : '' ) . '>' . esc_html__( 'Default', 'horizon' ) . '</option>
                            <option value="h2"' . ( $def_height == 'h2' ? ' selected' : '' ) . '>' . esc_html__( 'Tall', 'horizon' ) . '</option>
                        </select>',
            'value' =>  $def_height
        );

        $form_fields["gallery_width"] = array(
            'label' =>  esc_html__( 'Portfolio Template Width', 'horizon' ),
            'input' =>  'html',
            'html'  =>  '<select name="attachments[' . $post->ID . '][gallery_width]">
                            <option value=""' . ( !in_array( $def_width, array( 'w2' ) ) ? ' selected' : '' ) . '>' . esc_html__( 'Default', 'horizon' ) . '</option>
                            <option value="w2"' . ( $def_width == 'w2' ? ' selected' : '' ) . '>' . esc_html__( 'Wide', 'horizon' ) . '</option>
                        </select>',
            'value' =>  $def_width
        );

       return $form_fields;
    }

    /* Admin filters */

    // user profile - extra fields

	static function add_user_prof_fields( $user ) {
        $sn = get_the_author_meta( 'social_networks', $user->ID );
    	echo '<h3>' . esc_html__( 'Social Profiles', 'horizon' ) . '</h3>
    	<table class="form-table form-uexr">';
        if( !empty( $sn ) ) {
            foreach( $sn['icon'] as $k => $ic ) {
                if( !empty( $ic ) ) {
                    echo '<tr>
            			<th><label for="facebook">' . esc_html__( 'Network', 'horizon' ) . '</label></th>
            			<td>
            				<input type="text" name="social_networks[icon][]" id="social_networks[icon][]" value="' . esc_html( $ic ) . '" class="regular-text" placeholder="Icon" /><br />
            				<span class="description">' . esc_html__( 'Use Fontawesome icons', 'horizon' ) . '</span> <br />
            				<input type="text" name="social_networks[url][]" id="social_networks[url][]" value="' . esc_url( $sn['url'][$k] ) . '" class="regular-text" placeholder="URL" /><br />
            				<span class="description">' . esc_html__( 'Your social network profile (URL)', 'horizon' ) . '</span><br />
                            <a href="#" class="delete-uexr button">' . esc_html__( 'Delete', 'horizon' ) .'</a>
            			</td>
            		</tr>';
                }
            }
        }
        echo '
        <tr>
            <th></th>
            <td><a href="#" class="add-uexr button">' . esc_html__( 'Add Network', 'horizon' ) .'</a></td>
        </tr>
        <tr>
            <th><label for="facebook">' . esc_html__( 'Network', 'horizon' ) . '</label></th>
            <td>
                <input type="text" name="social_networks[icon][]" id="social_networks[icon][]" value="" class="regular-text" placeholder="Icon" /><br />
                <span class="description">' . esc_html__( 'Use Fontawesome icons', 'horizon' ) . '</span> <br />
                <input type="text" name="social_networks[url][]" id="social_networks[url][]" value="" class="regular-text" placeholder="URL" /><br />
                <span class="description">' . esc_html__( 'Your social network profile (URL)', 'horizon' ) . '</span><br />
                <a href="#" class="delete-uexr button">' . esc_html__( 'Delete', 'horizon' ) .'</a>
            </td>
        </tr>
    	</table>';
    }

    static function save_user_prof_fields( $user_id ) {
    	if ( !current_user_can( 'edit_user', $user_id ) ) return false;
        foreach( array( 'social_networks' ) as $k ) {
            if( isset( $_POST[$k] ) ) {
        	    update_user_meta( $user_id, $k, $_POST[$k] );
            }
        }
    }

}

add_filter( 'get_search_form', array( 'fastwp_horizon_theme\filters', 'search_form' ), 10 );
add_filter( 'the_password_form', array( 'fastwp_horizon_theme\filters', 'password_protected_form' ), 10, 2 );
add_action( 'wp_footer', array( 'fastwp_horizon_theme\filters', 'footer_content' ), 10 );
add_filter( 'comment_form_before', array( 'fastwp_horizon_theme\filters', 'before_comment_form' ), 10 );
add_filter( 'comment_form_after', array( 'fastwp_horizon_theme\filters', 'after_comment_form' ), 10 );
add_filter( 'comment_reply_link', array( 'fastwp_horizon_theme\filters', 'comment_reply_link' ), 10 );
add_action( 'edit_attachment', array( 'fastwp_horizon_theme\filters', 'save_attachment_location' ) );
add_filter( 'attachment_fields_to_edit', array( 'fastwp_horizon_theme\filters', 'image_attachment_fields_to_edit' ), null, 2);
add_action( 'show_user_profile',        array('fastwp_horizon_theme\filters','add_user_prof_fields' ) );
add_action( 'edit_user_profile',        array('fastwp_horizon_theme\filters','add_user_prof_fields' ) );
add_action( 'personal_options_update',  array('fastwp_horizon_theme\filters','save_user_prof_fields' ) );
add_action( 'edit_user_profile_update', array('fastwp_horizon_theme\filters','save_user_prof_fields' ) );