<?php

// FastWP Framework - markup

namespace fastwp_horizon_theme;

// Do not allow directly accessing this file.
if ( ! defined( 'ABSPATH' ) ) {
	die( 'Direct script access denied.' );
}

class markup {

    /* Get the menu */

    public static function the_menu( $menu = 'primary', $menu_class = 'menu', $first_only = false ) {
        $menu   = new \fastwp_horizon_core\menu_create( $menu );
        $links  = $menu->get_grouped_links();
        $markup = '';

        if( !empty( $links ) ) {
            $markup .= '<ul class="' . $menu_class . '">';

            foreach( $links as $link ) {
                $markup .= '<li' . ( !empty( $link['classes'] ) ? ' class="' . esc_attr( implode( ' ', $link['classes'] ) ) . '"' : '' ) . '>
                <a href="' . esc_url( $link['url'] ) . '" class="ajax-link' . ( !empty( $link['is_active'] ) || !empty( $link['children_is_active'] ) ? ' active' : '' ) . '"' .
                ( !empty( $link['target'] ) ? ' target="' . esc_attr( $link['target'] ) . '"' : '' ) . ( !empty( $link['attr_title'] ) ? ' title="' . esc_attr( $link['attr_title'] ) . '"' : '' ) . '>' . esc_html( $link['title'] ) . '</a>';
                if( !empty( $link['subnav'] ) && !$first_only ) {
                    self::the_submenu_links( $markup, $link['subnav'], $link['ID'] );
                }
                $markup .= '</li>';
            }

            $markup .= '</ul>';
        }

        return $markup;
    }

    /* Get the submenu */

    private static function the_submenu_links( &$markup, $main_link ) {
        $markup .= '<ul class="submenu">';

        foreach( $main_link as $link ) {
            $markup .= '<li' . ( !empty( $link['classes'] ) ? ' class="' . implode( ' ', $link['classes'] ) . '"' : '' ) . '>
            <a href="' . esc_url( $link['url'] ) . '"' . ( !empty( $link['is_active'] ) || !empty( $link['children_is_active'] ) ? ' class="active"' : '' ) .
            ( !empty( $link['target'] ) ? ' target="' . esc_html( $link['target'] ) . '"' : '' ) . ( !empty( $link['attr_title'] ) ? ' title="' . esc_html( $link['attr_title'] ) . '"' : '' ) . '>' . esc_html( $link['title'] ) . '</a>';

            if( !empty( $link['subnav'] ) ) {
                self::the_submenu_links( $markup, $link['subnav'] );
            }
            $markup .= '</li>';
        }

        $markup .= '</ul>';
    }

    /* Get the category */

    public static function the_category( $class = 'catg-name clr2', $post = 0 ) {
        $category = get_the_category( $post );
        if( !empty( $category ) ) {
            foreach( $category as $cat ) {
                return '<span class="' . esc_attr( $class ) . '">' . $cat->name . '</span>';
            }
        }
    }

    /* Search box */

    public static function search_box( $classes ) {
        $categories = $authors = array();
        foreach( get_categories() as $category ) {
            $categories[$category->term_id] = $category->name;
        }
        foreach( get_users( array( 'role__in' => array( 'administrator', 'author' ) ) ) as $user ) {
            $authors[$user->ID] = $user->display_name;
        } ?>
        <section class="<?php echo esc_attr( $classes ); ?>">
            <div class="container">
                <div class="form-sec-details">
                    <h2 class="sc-form-title"><?php echo sprintf( esc_html__( 'Hello! We have %s resources for you...', 'horizon' ), '<span class="big">' . wp_count_posts()->publish . '</span>' ); ?></h2>
                	<form action="<?php echo esc_url( home_url( '/' ) ); ?>" method="get">
                        <?php
                        $search = '<div class="col-12 col-lg-#col# col-md-#col#">
                            <div class="form-field field-with-icon pdr-70">
                                <i class="fa fa-search"></i>
                                <input type="text" name="s" placeholder="' . esc_html__( 'Type and hit enter...', 'horizon' ) . '">
                            </div>
                        </div>';
                        $category = '<div class="col-6 col-lg-3 col-md-3">
                            <div class="form-field">
                                <div class="custom-select">
                                    <select name="category">';
                                        if( !empty( $_GET['category'] ) && in_array( (int) $_GET['category'], array_keys( $categories ) ) ) {
                                            $category .= '<option value="' . (int) $_GET['category'] . '">' . $categories[(int) $_GET['category']] . '</option>';
                                        } else {
                                            $category .= '<option value="">' . esc_html__( 'Category', 'horizon' ) . '</option>';
                                        }
                                        $category .= '<option value="">' . esc_html__( 'All Categories', 'horizon' ) . '</option>';
                                        foreach( $categories as $category_id => $category_name ) {
                                            $category .= '<option value="' . $category_id . '">' . $category_name . '</option>';
                                        }
                                    $category .= '</select>
                                </div>
                            </div>
                        </div>';
                        $author = '<div class="col-6 col-lg-3 col-md-3">
                            <div class="form-field">
                                <div class="custom-select">
                                    <select name="author">';
                                        if( !empty( $_GET['author'] ) && in_array( (int) $_GET['author'], array_keys( $authors ) ) ) {
                                            $author .= '<option value="' . (int) $_GET['author'] . '">' . $authors[(int) $_GET['author']] . '</option>';
                                        } else {
                                            $author .= '<option value="">' . esc_html__( 'Author', 'horizon' ) . '</option>';
                                        }
                                        $author .= '<option value="">' . esc_html__( 'All authors', 'horizon' ) . '</option>';
                                        foreach( $authors as $user_id => $user_name ) {
                                            $author .= '<option value="' . $user_id . '">' . $user_name . '</option>';
                                        }
                                    $author .= '</select>
                                </div>
                            </div>
                        </div>';

                        $options = \fastwp_horizon_theme\utils::get_option( 'fwp_search_box_el' );
                        if( isset( $options['elements'] ) && count( $options['elements'] ) > 1 ) {
                            unset( $options['elements']['placebo'] );
                            foreach( $options['elements'] as $option_id => $option ) {
                                switch( $option_id ) {
                                    case 'text':
                                        $markup .= str_replace( '#col#', ( 12 - ( count( $options['elements'] ) - 1 ) * 3 ), $search );
                                    break;
                                    case 'category':
                                        $markup .= $category;
                                    break;
                                    case 'author':
                                        $markup .= $author;
                                    break;
                                }
                            }
                        } else {
                            $markup = str_replace( '#col#', 6, $search ) . "\n" . $category . "\n" . $author;
                        }

                        echo '<div class="row">' . $markup . '</div>'; ?>
                	</form>
                </div>
            </div>
        </section>
    <?php }

}