<?php

namespace fastwp_horizon_widgets;

// Do not allow directly accessing this file.
if ( ! defined( 'ABSPATH' ) ) {
	die( 'Direct script access denied.' );
}

class About extends \WP_Widget {

	function __construct() {
	    // widget title
	    parent::__construct( 'fastwp-about', esc_html__( 'About (FastWP)', 'horizon' ) );

        // register widget (do not modify)
        \fastwp_horizon_core\main::add_widget( __CLASS__ );
	}

    function widget( $args, $instance ) {
        $title = apply_filters( 'widget_title', $instance['title'] );

        echo ' ' . $args['before_widget'];

        echo '<div class="widget-about">';
        if( !empty( $instance['image'] ) ) {
            echo '<div class="about-img">
        		<img src="' . esc_url( $instance['image'] ) . '" alt="' . esc_html( $title ) . '" />
        	</div>';
        }
        if( !empty( $title ) ) {
            echo '<h3 class="widget-title">' . esc_html( $title ) . '</h3>';
        }
        echo '<p>' . esc_html( $instance['text'] ) . '</p>';
        if( !empty( $instance['signature'] ) ) {
	        echo '<img src="' . esc_url( $instance['signature'] ) . '" alt="' . esc_html__( 'Signature', 'horizon' ) . '" />';
        }
        echo '</div>' . $args['after_widget'];
    }

    function update( $new_instance, $old_instance ) {
        $instance = array();
        $instance['title']  = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
        $instance['image']  = ( ! empty( $new_instance['image'] ) ) ? $new_instance['image'] : '';
        $instance['text']   = ( ! empty( $new_instance['text'] ) ) ? $new_instance['text'] : '';
        $instance['signature'] = ( ! empty( $new_instance['signature'] ) ) ? $new_instance['signature'] : '';
        return $instance;
	}

	function form( $instance ) {
        $title  = isset( $instance['title'] ) ? $instance[ 'title' ] : esc_html__( 'Title', 'horizon' );
        $image  = isset( $instance['image'] ) ? $instance[ 'image' ] : '';
        $text   = isset( $instance['text'] ) ? $instance[ 'text' ] : '';
        $signature = isset( $instance['signature'] ) ? $instance[ 'signature' ] : '';

        echo '<p>
        <label for="' . $this->get_field_id( 'title' ) . '">' . esc_html__( 'Title:', 'horizon' ) . '</label>
        <input class="widefat" id="' . $this->get_field_id( 'title' ) . '>" name="' . $this->get_field_name( 'title' ) . '" type="text" value="' . esc_attr( $title ) . '" />
        </p>';
        echo '<p>
        <label for="' . $this->get_field_id( 'image' ) . '">' . esc_html__( 'Image:', 'horizon' ) . '</label>
        <input class="widefat" id="' . $this->get_field_id( 'image' ) . '>" name="' . $this->get_field_name( 'image' ) . '" type="text" value="' . esc_attr( $image ) . '" />
        </p>';
        echo '<p>
        <label for="' . $this->get_field_id( 'Text' ) . '">' . esc_html__( 'Text:', 'horizon' ) . '</label>
        <textarea id="' . $this->get_field_id( 'text' ) . '" name="' . $this->get_field_name( 'text' ) . '" style="width: 100%;">' . esc_attr( $text ) . '</textarea>
        </p>';
        echo '<p>
        <label for="' . $this->get_field_id( 'signature' ) . '">' . esc_html__( 'Signature:', 'horizon' ) . '</label>
        <input class="widefat" id="' . $this->get_field_id( 'signature' ) . '>" name="' . $this->get_field_name( 'signature' ) . '" type="text" value="' . esc_attr( $signature ) . '" />
        </p>';
	}

}

?>