<?php

namespace fastwp_horizon_widgets;

// Do not allow directly accessing this file.
if ( ! defined( 'ABSPATH' ) ) {
	die( 'Direct script access denied.' );
}

class Instagram extends \WP_Widget {

	function __construct() {
	    // widget title
	    parent::__construct( 'fastwp-instagram', esc_html__( 'Instagram Images (FastWP)', 'horizon' ) );

        // register widget (do not modify)
        \fastwp_horizon_core\main::add_widget( __CLASS__ );
	}

    function widget( $args, $instance ) {
        $title = apply_filters( 'widget_title', $instance['title'] );

        echo ' ' . $args['before_widget'];

        echo '<div class="widget-instagram">';
        if( !empty( $title ) ) {
            echo '<h3 class="widget-title">' . esc_html( $title ) . '</h3>';
        }

        if( class_exists( 'Fastwp_Instagram_Client' ) ) {

        $media = new \Fastwp_Instagram_Client;
        $media->setToken( get_option( 'horizon_access_token' ) );
        $media_photos = $media->getMedia( $instance['limit'] );
        $media_error = $media->getError();

        if( empty( $media_error ) && is_array( $media_photos->data ) ) {
            echo '<ul class="insta-pics">';
            foreach( $media_photos->data as $photo ) {
                echo '<li><a href="' . esc_url( $photo->link ) . '"><img src="' .  $photo->images->standard_resolution->url . '" alt="' . esc_attr__( 'Instagram image', 'horizon' ) . '" /></a></li>';
            }
            echo '</ul>';
        }

        }

        echo '</div>' . $args['after_widget'];
    }

    function update( $new_instance, $old_instance ) {
        $instance = array();
        $instance['title']  = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
        $instance['limit']  = ( ! empty( $new_instance['limit'] ) ) ? $new_instance['limit'] : '';
        $instance['profile']= ( ! empty( $new_instance['profile'] ) ) ? $new_instance['profile'] : '';
        return $instance;
	}

	function form( $instance ) {
        $title  = isset( $instance['title'] ) ? $instance[ 'title' ] : esc_html__( 'Title', 'horizon' );
        $limit  = isset( $instance['limit'] ) ? $instance[ 'limit' ] : 6;
        $profile= isset( $instance['profile'] ) ? $instance[ 'profile' ] : '';

        echo '<p>
        <label for="' . $this->get_field_id( 'title' ) . '">' . esc_html__( 'Title:', 'horizon' ) . '</label>
        <input class="widefat" id="' . $this->get_field_id( 'title' ) . '>" name="' . $this->get_field_name( 'title' ) . '" type="text" value="' . esc_attr( $title ) . '" />
        </p>';
        echo '<p>
        <label for="' . $this->get_field_id( 'limit' ) . '">' . esc_html__( 'Limit:', 'horizon' ) . '</label>
        <input class="widefat" id="' . $this->get_field_id( 'limit' ) . '>" name="' . $this->get_field_name( 'limit' ) . '" type="number" value="' . (int) $limit . '" />
        </p>';
        echo '<p>
        <label for="' . $this->get_field_id( 'profile' ) . '">' . esc_html__( 'Profile:', 'horizon' ) . '</label>
        <input class="widefat" id="' . $this->get_field_id( 'profile' ) . '>" name="' . $this->get_field_name( 'profile' ) . '" type="text" value="' . esc_attr( $profile ) . '" />
        </p>';
	}

}

?>