<?php

namespace fastwp_horizon_widgets;

// Do not allow directly accessing this file.
if ( ! defined( 'ABSPATH' ) ) {
	die( 'Direct script access denied.' );
}

class PopularPosts extends \WP_Widget {

	function __construct() {
	    // widget title
	    parent::__construct( 'fastwp-popular-posts', esc_html__( 'Popular Posts (FastWP)', 'horizon' ) );

        // register widget (do not modify)
        \fastwp_horizon_core\main::add_widget( __CLASS__ );
	}

    function widget( $args, $instance ) {
        $title = apply_filters( 'widget_title', $instance['title'] );

        echo ' ' . $args['before_widget'];    

        echo '<div class="widget-posts">';
        if( !empty( $title ) ) {
            echo '<h3 class="widget-title">' . esc_html( $title ) . '</h3>';
        }

        $fastwp_horizon_posts = new \WP_Query(
        array(
            'posts_per_page' => $instance['limit'],
            'meta_query2' => array(
                array(
                    'key'      => 'post_popular',
                    'value'    => '1',
                    'type'     => 'CHAR',
                    'compare'  => '='
                ) )
        ) );

        if( $fastwp_horizon_posts->have_posts() ) { ?>
        <ul class="small-posts">
        <?php while( $fastwp_horizon_posts->have_posts() ) {
        $fastwp_horizon_posts->the_post(); ?>
        	<li class="small-post">
                <?php if( has_post_thumbnail() && !post_password_required() && !is_attachment() ) { ?>
                <img src="<?php echo get_the_post_thumbnail_url(); ?>" alt="<?php the_title_attribute(); ?>" />
                <?php } ?>
                <div class="small-post-info">
                    <h3><a href="<?php the_permalink(); ?>"><?php the_title_attribute(); ?></a></h3>
                </div>
        	</li>
        <?php } ?>
        </ul>
        <?php wp_reset_postdata();
        }

        echo '</div>' . $args['after_widget'];
    }

    function update( $new_instance, $old_instance ) {
        $instance = array();
        $instance['title']  = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
        $instance['limit']  = ( ! empty( $new_instance['limit'] ) ) ? $new_instance['limit'] : '';
        return $instance;
	}

	function form( $instance ) {
        $title  = isset( $instance['title'] ) ? $instance[ 'title' ] : esc_html__( 'Popular Posts', 'horizon' );
        $limit  = isset( $instance['limit'] ) ? $instance[ 'limit' ] : 3;

        echo '<p>
        <label for="' . $this->get_field_id( 'title' ) . '">' . esc_html__( 'Title:', 'horizon' ) . '</label>
        <input class="widefat" id="' . $this->get_field_id( 'title' ) . '>" name="' . $this->get_field_name( 'title' ) . '" type="text" value="' . esc_attr( $title ) . '" />
        </p>';
        echo '<p>
        <label for="' . $this->get_field_id( 'limit' ) . '">' . esc_html__( 'Limit:', 'horizon' ) . '</label>
        <input class="widefat" id="' . $this->get_field_id( 'limit' ) . '>" name="' . $this->get_field_name( 'limit' ) . '" type="number" value="' . (int) $limit . '" />
        </p>';
	}

}

?>