<?php

namespace fastwp_horizon_widgets;

// Do not allow directly accessing this file.
if ( ! defined( 'ABSPATH' ) ) {
	die( 'Direct script access denied.' );
}

class Tags extends \WP_Widget {

	function __construct() {
	    // widget title
	    parent::__construct( 'fastwp-tags', esc_html__( 'Tags (FastWP)', 'horizon' ) );

        // register widget (do not modify)
        \fastwp_horizon_core\main::add_widget( __CLASS__ );
	}

    function widget( $args, $instance ) {
        $title = apply_filters( 'widget_title', $instance['title'] );

        echo ' ' . $args['before_widget'];    

        echo '<div class="widget-tags">';
        if( !empty( $title ) ) {
            echo '<h3 class="widget-title">' . esc_html( $title ) . '</h3>';
        }

        $fastwp_horizon_tags = get_tags( array(
            'taxonomy'  => 'post_tag',
            'orderby'   => 'count',
            'order'     => 'DESC',
            'number'    => $instance['tags'],
            'hide_empty'=> false,
        ) );

        if( !empty( $fastwp_horizon_tags ) ) {
            echo '<ul class="tags-list">';
            foreach( $fastwp_horizon_tags as $fastwp_horizon_tag ) {
                echo '<li><a href="' . get_tag_link( $fastwp_horizon_tag->term_id ) . '">' . esc_html( $fastwp_horizon_tag->name ) . '</a></li>';
            }
            echo '</ul>';
        }

        echo '</div>' . $args['after_widget'];
    }

    function update( $new_instance, $old_instance ) {
        $instance = array();
        $instance['title']  = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
        $instance['tags']   = ( ! empty( $new_instance['tags'] ) ) ? $new_instance['tags'] : '';
        return $instance;
	}

	function form( $instance ) {
        $title  = isset( $instance['title'] ) ? $instance[ 'title' ] : esc_html__( 'Title', 'horizon' );
        $tags   = isset( $instance['tags'] ) ? $instance[ 'tags' ] : '';

        echo '<p>
        <label for="' . $this->get_field_id( 'title' ) . '">' . esc_html__( 'Title:', 'horizon' ) . '</label>
        <input class="widefat" id="' . $this->get_field_id( 'title' ) . '>" name="' . $this->get_field_name( 'title' ) . '" type="text" value="' . esc_attr( $title ) . '" />
        </p>';
        echo '<p>
        <label for="' . $this->get_field_id( 'tags' ) . '">' . esc_html__( 'Tags:', 'horizon' ) . '</label>
        <input class="widefat" id="' . $this->get_field_id( 'tags' ) . '>" name="' . $this->get_field_name( 'tags' ) . '" type="number" value="' . esc_attr( $tags ) . '" />
        </p>';
	}

}

?>