<?php

// Do not allow directly accessing this file.
if ( ! defined( 'ABSPATH' ) ) {
	die( 'Direct script access denied.' );
}

/*** Define Horizon Theme constants ***/

if( !defined( 'FASTWP_HORIZON_FRAMEWORK_DIR' ) ) {
    define( 'FASTWP_HORIZON_FRAMEWORK_DIR', 'fastwp-framework' );
}

if( !defined( 'FASTWP_HORIZON_DIR' ) ) {
    define( 'FASTWP_HORIZON_DIR', get_template_directory() );
}

if( !defined( 'FASTWP_HORIZON_URI' ) ) {
    define( 'FASTWP_HORIZON_URI', get_template_directory_uri() );
}

/*** Autoload ***/

require_once FASTWP_HORIZON_DIR . '/' . FASTWP_HORIZON_FRAMEWORK_DIR . '/autoload.php';

/*** General ***/

if ( ! isset( $content_width ) ) $content_width = 900;
if ( is_singular() ) wp_enqueue_script( "comment-reply" );

/*** Redux framework ***/

new fastwp_horizon_core\redux;

// Theme support

fastwp_horizon_core\general::add_theme_support( 'menus,custom-logo,title-tag,post-thumbnails,automatic-feed-links' );
fastwp_horizon_core\general::add_theme_support( 'post-formats',
    array(
        'image',
        'video',
        'gallery'
    )
);

add_action( 'init', array( 'fastwp_horizon_core\general', 'register_theme_support' ), 1 );

// Add menu location

fastwp_horizon_core\menu::add_menu( 'primary',         esc_html__( 'Main Menu', 'horizon' ) );
fastwp_horizon_core\menu::add_menu( 'mobile-menu',     esc_html__( 'Mobile Menu', 'horizon' ) );
fastwp_horizon_core\menu::add_menu( 'second-menu',     esc_html__( 'Overlay Secondary Menu (only one level accepted)', 'horizon' ) );
fastwp_horizon_core\menu::add_menu( 'footer_links',    esc_html__( 'Footer Links (only one level accepted)', 'horizon' ) );

// Language dir used for translation

fastwp_horizon_core\general::text_domain_language_dir( 'horizon' );

/*** List of the styles used in Horizon Theme ***/

fastwp_horizon_core\main::add_styles( FASTWP_HORIZON_URI . '/assets/js/lib/slick',
    array(
        'slick',
        'slick-theme'
    )
);

fastwp_horizon_core\main::add_styles( FASTWP_HORIZON_URI . '/assets/css',
    array(
        'animate',
        'bootstrap.min',
        'line-awesome.min',
        'font-awesome.min',
        'color',
        'style',
        'responsive',
        'wp'
    )
);

fastwp_horizon_core\main::add_styles( 'https://fonts.googleapis.com/css?family=',
    array(
        'Roboto:300,300i,400,400i,500,500i,700,700i,900,900i'
    ),
    true,
    'google-fonts'
);

fastwp_horizon_core\main::add_admin_styles( FASTWP_HORIZON_URI . '/assets/css',
    array(
        'admin'
    )
);

/*** List of the javascript files used in Horizon Theme ***/

fastwp_horizon_core\main::add_scripts( FASTWP_HORIZON_URI  . '/assets/js',
    array(
        'popper',
        'bootstrap.min',
        'isotope',
        'placeholdem.min',
        'html5lightbox',
        'custom-select',
        'script'
    )
);

fastwp_horizon_core\main::add_scripts( FASTWP_HORIZON_URI  . '/assets/js',
    array(
        'lib/slick/slick'
    )
);

fastwp_horizon_core\main::add_admin_scripts( FASTWP_HORIZON_URI . '/assets/js',
    array(
        'admin'
    )
);

fastwp_horizon_core\main::add_script_deps( 'script', array( 'jquery' ) );

if( fastwp_horizon_theme\utils::get_option( 'fwp_gmap_key' ) !== '' ) {
    fastwp_horizon_core\main::add_scripts( FASTWP_HORIZON_URI  . '/assets/js',
        array(
            'custom'
        )
    );

    fastwp_horizon_core\main::add_scripts( '//maps.googleapis.com/maps/api/js?key=' . fastwp_horizon_theme\utils::get_option( 'fwp_gmap_key' ) );
}

/*** List of required plugins ***/

fastwp_horizon_core\tgmpa::add_plugin( 'contact-form-7',
    array(
        'name'      => esc_html__( 'Contact form 7', 'horizon' ),
        'required'  => false
    )
);

fastwp_horizon_core\tgmpa::add_plugin( 'mailchimp-for-wp',
    array(
        'name'      => esc_html__( 'Mailchimp for WordPress', 'horizon' ),
        'required'  => false
    )
);

fastwp_horizon_core\tgmpa::add_plugin( 'functionality-for-horizon-theme',
    array(
        'name'      => esc_html__( 'Horizon Theme Functionality', 'horizon' ),
        'source'    => FASTWP_HORIZON_DIR . '/' . FASTWP_HORIZON_FRAMEWORK_DIR . '/plugins/functionality-for-horizon-theme.zip',
        'required'  => false
    )
);

fastwp_horizon_core\tgmpa::add_plugin( 'fastwp-redux-horizon-extension',
    array(
        'name'      => esc_html__( 'Redux Theme Options for Horizon Theme', 'horizon' ),
        'source'    => FASTWP_HORIZON_DIR . '/' . FASTWP_HORIZON_FRAMEWORK_DIR . '/plugins/fastwp-redux-horizon-extension.zip',
        'required'  => false
    )
);

/*** Add widget areas ***/

fastwp_horizon_core\main::add_widget_area( 'sidebar-1', esc_html__( 'Horizon Widgets', 'horizon' ),
    array(
        'description'   => esc_html__( 'Widgets used in Horizon theme', 'horizon' ),
    )
);

fastwp_horizon_core\main::add_widget_area( 'sidebar-2', esc_html__( 'Advertise Sidebar', 'horizon' ),
    array(
        'description'   => esc_html__( 'Only "Custom HTML" widget allowed. Section used work only with Grid blog type.', 'horizon' ),
    )
);

function fastwp_horizon_widgets_filter( $sidebars_widgets ) {
    if( !empty( $sidebars_widgets['sidebar-2'] ) ) {
        foreach( $sidebars_widgets['sidebar-2'] as $k => $v ) {
            if( 'custom_html' !== strtok( $v, '-' ) ) {
                unset( $sidebars_widgets['sidebar-2'][$k] );
            }
        }
    }
    return $sidebars_widgets;
}

add_action( 'sidebars_widgets', 'fastwp_horizon_widgets_filter' );

/*** Init custom filters ***/

new fastwp_horizon_theme\filters;


/*** Customizer ***/

add_action( 'customize_register', array( 'fastwp_horizon_customizer\customizer', 'register' ), 1 );

/*** Horizon Theme ***/

new fastwp_horizon_core\checker;

?>
